bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDToGaussianWishart.lower_bound_contribution
===============================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDToGaussianWishart.lower_bound_contribution